var labelType, useGradients, nativeTextSupport, animate;

$(function(){
  var ua = navigator.userAgent,
      iStuff = ua.match(/iPhone/i) || ua.match(/iPad/i),
      typeOfCanvas = typeof HTMLCanvasElement,
      nativeCanvasSupport = (typeOfCanvas == 'object' || typeOfCanvas == 'function'),
      textSupport = nativeCanvasSupport
        && (typeof document.createElement('canvas').getContext('2d').fillText == 'function');
  //I'm setting this based on the fact that ExCanvas provides text support for IE
  //and that as of today iPhone/iPad current text support is lame
  labelType = (!nativeCanvasSupport || (textSupport && !iStuff))? 'Native' : 'HTML';
  nativeTextSupport = labelType == 'Native';
  useGradients = nativeCanvasSupport;
  animate = !(iStuff || !nativeCanvasSupport);

  init();
});

function init(){
    //init Spacetree
    //Create a new ST instance
    var st = new $jit.ST({
        //id of viz container element
        injectInto: 'issue_tree_wrapper',
        //set duration for the animation
        duration: 300,
        //set animation transition type
        transition: $jit.Trans.Quart.easeInOut,
        //set distance between node and its children
        levelDistance: 50,
        //enable panning
        Navigation: {
          enable:true,
          panning:true
        },
        //set node and edge styles
        //set overridable=true for styling individual
        //nodes or edges
        Node: {
            height: 24,
            width: 180,
            type: 'rectangle',
            color: '#DDD',
            overridable: true
        },

        Edge: {
            type: 'bezier'
        },

        //This method is called on DOM label creation.
        //Use this method to add event handlers and styles to
        //your node.
        onCreateLabel: function(label, node){
            label.id = node.id;
            label.innerHTML = node.name + ' <a href="' + Drupal.settings.basePath + 'node/' + node.data.nid + '">[view]</a>';
            label.onclick = function(){st.onClick(node.id);};
            //set label styles
            var style = label.style;
            style.width = 180 + 'px';
            style.height = 18 + 'px';
            style.cursor = 'pointer';
            style.color = '#333';
            style.fontSize = '0.8em';
            style.textAlign= 'center';
            style.paddingTop = '2px';
        },

        onBeforePlotNode: function(node){
            if (node.data.status == 'warning') {
                node.data.$color = "#FFC9A0";
            } else if (node.data.status == 'error') {
                node.data.$color = "#FFA0A0";
            } else {
                node.data.$color = "#DDD"
            }
            if (node.selected) {
                node.data.$color = "#ff7";
            }
        },

        onBeforePlotLine: function(adj){
            if (adj.nodeFrom.selected && adj.nodeTo.selected) {
                adj.data.$color = "#eed";
                adj.data.$lineWidth = 3;
            }
            else {
                delete adj.data.$color;
                delete adj.data.$lineWidth;
            }
        },

        Tips: {
            enable: true,
            type: 'native',
            onShow: function(tip, node) {
                tip.innerHTML = node.data.issue_summary;
            }
        }
    });
    //load json data
    st.loadJSON(Drupal.settings.issue_tree);
    //compute node positions and layout
    st.compute();
    //optional: make a translation of the tree
    st.geom.translate(new $jit.Complex(-200, 0), "current");
    //emulate a click on the root node.
    st.onClick(st.root);
}
